@@ -8,16 +8,19 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.assertions._jsii
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_events_targets._jsii
-import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_logs._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-events-notify", "0.2.42", __name__[0:-6], "cdk-events-notify@0.2.42.jsii.tgz"
+    "cdk-events-notify",
+    "1.0.168",
+    __name__[0:-6],
+    "cdk-events-notify@1.0.168.jsii.tgz",
 )
 
 __all__ = [
